# Changelog

## 0.11.0 - 2025-06-13

* support for deleting entries in the database, both in server and web client

## 0.10.0 - 2024-12-09

* more debugging when --debug is used
* doc updated

## 0.9.13 - 2024-12-02

* packaged as a pip-installable package as `r2lab-sidecar`
* using `pyproject.toml` for packaging
